==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/FormatSpecifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSpecifierDescription } from "./FormatSpecifierDescription";
/**
 * @hidden
 */
var FormatSpecifierDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatSpecifierDescriptionMetadata, _super);
    function FormatSpecifierDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatSpecifierDescriptionMetadata.b = function (a) {
        if (FormatSpecifierDescriptionMetadata.a == null) {
            FormatSpecifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatSpecifierDescriptionMetadata.c(FormatSpecifierDescriptionMetadata.a);
        }
        if (a.g(FormatSpecifierDescriptionMetadata.a)) {
            return;
        }
        a.s(FormatSpecifierDescriptionMetadata.a);
    };
    FormatSpecifierDescriptionMetadata.c = function (a) {
    };
    FormatSpecifierDescriptionMetadata.d = function (a) {
        FormatSpecifierDescriptionMetadata.b(a);
        a.u("FormatSpecifier", function () { return new FormatSpecifierDescription(); });
        a.t("FormatSpecifier", FormatSpecifierDescriptionMetadata.a);
    };
    FormatSpecifierDescriptionMetadata.$t = markType(FormatSpecifierDescriptionMetadata, 'FormatSpecifierDescriptionMetadata');
    FormatSpecifierDescriptionMetadata.a = null;
    return FormatSpecifierDescriptionMetadata;
}(Base));
export { FormatSpecifierDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FormatSpecifierDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSpecifierDescription } from "./FormatSpecifierDescription";
/**
 * @hidden
 */
var FormatSpecifierDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatSpecifierDescriptionMetadata, _super);
    function FormatSpecifierDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatSpecifierDescriptionMetadata.b = function (a) {
        if (FormatSpecifierDescriptionMetadata.a == null) {
            FormatSpecifierDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatSpecifierDescriptionMetadata.c(FormatSpecifierDescriptionMetadata.a);
        }
        if (a.j(FormatSpecifierDescriptionMetadata.a)) {
            return;
        }
        a.y(FormatSpecifierDescriptionMetadata.a);
    };
    FormatSpecifierDescriptionMetadata.c = function (a) {
    };
    FormatSpecifierDescriptionMetadata.d = function (a) {
        FormatSpecifierDescriptionMetadata.b(a);
        a.aa("FormatSpecifier", function () { return new FormatSpecifierDescription(); });
        a.z("FormatSpecifier", FormatSpecifierDescriptionMetadata.a);
    };
    FormatSpecifierDescriptionMetadata.$t = markType(FormatSpecifierDescriptionMetadata, 'FormatSpecifierDescriptionMetadata');
    FormatSpecifierDescriptionMetadata.a = null;
    return FormatSpecifierDescriptionMetadata;
}(Base));
export { FormatSpecifierDescriptionMetadata };
